@@ -235,7 +235,7 @@ fn get_sysvar<T: Default + Sysvar + Sized + serde::de::DeserializeOwned>(
 
 struct SyscallStubs {}
 impl gemachain_sdk::program_stubs::SyscallStubs for SyscallStubs {
-    fn sol_log(&self, message: &str) {
+    fn gema_log(&self, message: &str) {
         let invoke_context = get_invoke_context();
         let logger = invoke_context.get_logger();
         let logger = logger.borrow_mut();
@@ -244,7 +244,7 @@ impl gemachain_sdk::program_stubs::SyscallStubs for SyscallStubs {
         }
     }
 
-    fn sol_invoke_signed(
+    fn gema_invoke_signed(
         &self,
         instruction: &Instruction,
         account_infos: &[AccountInfo],
@@ -372,20 +372,20 @@ impl gemachain_sdk::program_stubs::SyscallStubs for SyscallStubs {
         Ok(())
     }
 
-    fn sol_get_clock_sysvar(&self, var_addr: *mut u8) -> u64 {
+    fn gema_get_clock_sysvar(&self, var_addr: *mut u8) -> u64 {
         get_sysvar::<Clock>(&clock::id(), var_addr)
     }
 
-    fn sol_get_epoch_schedule_sysvar(&self, var_addr: *mut u8) -> u64 {
+    fn gema_get_epoch_schedule_sysvar(&self, var_addr: *mut u8) -> u64 {
         get_sysvar::<EpochSchedule>(&epoch_schedule::id(), var_addr)
     }
 
     #[allow(deprecated)]
-    fn sol_get_fees_sysvar(&self, var_addr: *mut u8) -> u64 {
+    fn gema_get_fees_sysvar(&self, var_addr: *mut u8) -> u64 {
         get_sysvar::<Fees>(&fees::id(), var_addr)
     }
 
-    fn sol_get_rent_sysvar(&self, var_addr: *mut u8) -> u64 {
+    fn gema_get_rent_sysvar(&self, var_addr: *mut u8) -> u64 {
         get_sysvar::<Rent>(&rent::id(), var_addr)
     }
 }
@@ -485,7 +485,7 @@ impl Default for ProgramTest {
     ///
     fn default() -> Self {
         gemachain_logger::setup_with_default(
-            "solana_rbpf::vm=debug,\
+            "gemachain_rbpf::vm=debug,\
              gemachain_runtime::message_processor=debug,\
              gemachain_runtime::system_instruction_processor=trace,\
              gemachain_program_test=info",
